%global pkgname genss

Name:           gap-pkg-%{pkgname}
Version:        1.6.5
Release:        1%{?dist}
Summary:        Randomized Schreier-Sims algorithm

License:        GPLv3+
URL:            https://gap-packages.github.io/genss/
Source0:        https://github.com/gap-packages/genss/releases/download/v%{version}/%{pkgname}-%{version}.tar.bz2
BuildArch:      noarch

# The AtlasRep and CtblLib dependencies are needed for the tests only
BuildRequires:  gap-devel
BuildRequires:  gap-pkg-atlasrep
BuildRequires:  gap-pkg-autodoc
BuildRequires:  gap-pkg-ctbllib
BuildRequires:  gap-pkg-io
BuildRequires:  gap-pkg-orb

Requires:       gap-core%{?_isa}
Requires:       gap-pkg-io
Requires:       gap-pkg-orb

%description
The genss package implements the randomized Schreier-Sims algorithm to
compute a stabilizer chain and a base and strong generating set for
arbitrary finite groups.

%prep
%autosetup -n %{pkgname}-%{version}

# Fix encodings
for fil in init.g read.g doc/examples.xml doc/intro.xml; do
  iconv -f iso8859-1 -t utf-8 $fil > $fil.utf8
  touch -r $fil $fil.utf8
  mv -f $fil.utf8 $fil
done

%build
export LC_ALL=C.UTF-8
gap makedoc.g

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg/%{pkgname}
cp -a doc gap test VERSION *.g %{buildroot}%{_gap_dir}/pkg/%{pkgname}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/clean
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,tex,toc}

%check
export LC_ALL=C.UTF-8

# Skip tests that generate HTTP traffic to the ATLAS database
sed -e 's/\[1,2,3,4,5,6,7,8,14\]/[1..7]/' \
    -e 's/1\.\.4/2/' \
    -e 's/1\.\.25/1..6/' \
    -e 's/1\.\.26/1..5/' \
    -e 's/\[1,2,3,4,5,6,7,8,11,16,17,19,20\]/[1..7]/' \
    -e 's/\[1,2,3\]/[1]/' \
    -e 's/\[1,2,4,6\]/[1,2,3]/' \
    -i test/testall.g

gap -l "%{buildroot}%{_gap_dir};%{_gap_dir};" << EOF 2>&1 | tee log
LoadPackage( "genss" );
Read( "test/testall.g" );
EOF
! grep -Fq fail log
rm -f log

%files
%doc CHANGES README
%license GPL
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Mon Jan  8 2018 Jerry James <loganjerry@gmail.com> - 1.6.5-1
- New upstream version

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 1.6.4-1
- New upstream version

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan  8 2016 Jerry James <loganjerry@gmail.com> - 1.6.3-1
- New upstream version
- Update URLs

* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 1.6.2-2
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source
- Turn test failures into build failures

* Tue Jul 28 2015 Jerry James <loganjerry@gmail.com> - 1.6.2-1
- Initial RPM
